@@ -20,6 +20,16 @@
 
 """This file contains the version of the Translate Toolkit."""
 
-build = 12016
-sver = "1.10.0"
-ver = (1, 10, 0)
+build = 12021
+"""The build number is used by external users of the Translate Toolkit to
+trigger refreshes.  Thus increase the build number whenever changes are made to
+code touching stats or quality checks.  An increased build number will force a
+toolkit user, like Pootle, to regenerate it's stored stats and check
+results."""
+
+sver = "1.12.0"
+"""Human readable version number. Used for version number display."""
+
+ver = (1, 12, 0)
+"""Machine readable version number. Used by tools that need to adjust code
+paths based on a Translate Toolkit release number."""
