@@ -24,6 +24,7 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+from translate.convert import convert
 from translate.storage import factory
 
 
@@ -50,8 +51,13 @@ class rejson:
         return str(self.templatestore)
 
 
-def convertjson(inputfile, outputfile, templatefile, includefuzzy=False):
+def convertjson(inputfile, outputfile, templatefile, includefuzzy=False,
+                outputthreshold=None):
     inputstore = factory.getobject(inputfile)
+
+    if not convert.should_output_store(inputstore, outputthreshold):
+        return False
+
     if templatefile is None:
         raise ValueError("Must have template file for JSON files")
     else:
@@ -63,12 +69,12 @@ def convertjson(inputfile, outputfile, templatefile, includefuzzy=False):
 
 def main(argv=None):
     # handle command line options
-    from translate.convert import convert
     formats = {
                ("po", "json"): ("json", convertjson),
               }
     parser = convert.ConvertOptionParser(formats, usetemplates=True,
                                          description=__doc__)
+    parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.run(argv)
 
