@@ -24,8 +24,8 @@
 """Convert Gettext PO localization files to Mozilla .lang files.
 """
 
-from translate.storage import mozilla_lang as lang
-from translate.storage import po
+from translate.convert import convert
+from translate.storage import mozilla_lang as lang, po
 
 
 class po2lang:
@@ -52,10 +52,15 @@ class po2lang:
         return thetargetfile
 
 
-def convertlang(inputfile, outputfile, templates, includefuzzy=False, mark_active=True):
+def convertlang(inputfile, outputfile, templates, includefuzzy=False, mark_active=True,
+                outputthreshold=None, remove_untranslated=None):
     """reads in stdin using fromfileclass, converts using convertorclass,
     writes to stdout"""
     inputstore = po.pofile(inputfile)
+
+    if not convert.should_output_store(inputstore, outputthreshold):
+        return False
+
     if inputstore.isempty():
         return 0
     convertor = po2lang(mark_active=mark_active)
@@ -71,7 +76,6 @@ formats = {
 
 
 def main(argv=None):
-    from translate.convert import convert
     from translate.misc import stdiotell
     import sys
     sys.stdout = stdiotell.StdIOWrapper(sys.stdout)
@@ -79,6 +83,7 @@ def main(argv=None):
                                            description=__doc__)
     parser.add_option("", "--mark-active", dest="mark_active", default=False,
             action="store_true", help="mark the file as active")
+    parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.passthrough.append("mark_active")
     parser.run(argv)
