@@ -24,9 +24,10 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+from translate.convert import convert
 from translate.misc import quote
-from translate.storage import po
-from translate.storage import php
+from translate.storage import php, po
+
 
 eol = "\n"
 
@@ -140,8 +141,13 @@ class rephp:
         return returnline
 
 
-def convertphp(inputfile, outputfile, templatefile, includefuzzy=False):
+def convertphp(inputfile, outputfile, templatefile, includefuzzy=False,
+               outputthreshold=None):
     inputstore = po.pofile(inputfile)
+
+    if not convert.should_output_store(inputstore, outputthreshold):
+        return False
+
     if templatefile is None:
         raise ValueError("must have template file for php files")
         # convertor = po2php()
@@ -154,13 +160,13 @@ def convertphp(inputfile, outputfile, templatefile, includefuzzy=False):
 
 def main(argv=None):
     # handle command line options
-    from translate.convert import convert
     formats = {
             ("po", "php"): ("php", convertphp),
             ("po", "html"): ("html", convertphp),
     }
     parser = convert.ConvertOptionParser(formats, usetemplates=True,
                                          description=__doc__)
+    parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.run(argv)
 
