@@ -24,13 +24,48 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
+import warnings
+
+from translate.convert import accesskey, convert
 from translate.misc import quote
-from translate.storage import po
-from translate.storage import properties
+from translate.storage import po, properties
+
 
 eol = u"\n"
 
 
+def applytranslation(key, propunit, inunit, mixedkeys):
+    """applies the translation for key in the po unit to the prop unit"""
+    # this converts the po-style string to a prop-style string
+    value = inunit.target
+    # handle mixed keys
+    for labelsuffix in properties.labelsuffixes:
+        if key.endswith(labelsuffix):
+            if key in mixedkeys:
+                value, akey = accesskey.extract(value)
+                break
+    else:
+        for akeysuffix in properties.accesskeysuffixes:
+            if key.endswith(akeysuffix):
+                if key in mixedkeys:
+                    label, value = accesskey.extract(value)
+                    if not value:
+                        warnings.warn("Could not find accesskey for %s" % key)
+                        # Use the source language accesskey
+                        label, value = accesskey.extract(inunit.source)
+                    else:
+                        original = propunit.source
+                        # For the sake of diffs we keep the case of the
+                        # accesskey the same if we know the translation didn't
+                        # change. Casing matters in XUL.
+                        if value == propunit.source and original.lower() == value.lower():
+                            if original.isupper():
+                                value = value.upper()
+                            elif original.islower():
+                                value = value.lower()
+    return value
+
+
 class reprop:
 
     def __init__(self, templatefile, inputstore, personality, encoding=None,
@@ -42,6 +77,8 @@ class reprop:
         if self.encoding is None:
             self.encoding = self.personality.default_encoding
         self.remove_untranslated = remove_untranslated
+        self.mixer = accesskey.UnitMixer(properties.labelsuffixes,
+                                         properties.accesskeysuffixes)
 
     def convertstore(self, includefuzzy=False):
         self.includefuzzy = includefuzzy
@@ -58,6 +95,20 @@ class reprop:
             outputlines.append(outputstr)
         return u"".join(outputlines).encode(self.encoding)
 
+
+    def _handle_accesskeys(self, inunit, currkey):
+        value = inunit.target
+        if self.personality.name == "mozilla":
+            keys = inunit.getlocations()
+            mixedkeys = self.mixer.match_entities(keys)
+            for key in keys:
+                if key == currkey and key in self.inputstore.locationindex:
+                    propunit = self.inputstore.locationindex[key]  # find the prop
+                    value = applytranslation(key, propunit, inunit, mixedkeys)
+                    break
+
+        return value
+
     def _explode_gaia_plurals(self):
         """Explode the gaia plurals."""
         from translate.lang import data
@@ -75,7 +126,7 @@ class reprop:
                 if category == 'zero':
                     # [zero] cases are translated as separate units
                     continue
-                new_unit = self.inputstore.addsourceunit(u"fish") # not used
+                new_unit = self.inputstore.addsourceunit(u"fish")  # not used
                 new_location = '%s[%s]' % (location, category)
                 new_unit.addlocation(new_location)
                 new_unit.target = text
@@ -115,28 +166,26 @@ class reprop:
                 delimiter = prespace + delimiter_char + postspace
             if key in self.inputstore.locationindex:
                 unit = self.inputstore.locationindex[key]
-                if self.remove_untranslated and (unit.source == unit.target or
-                                                 unit.isfuzzy() or
-                                                 len(unit.target) == 0):
+                if not unit.istranslated() and bool(unit.source) and self.remove_untranslated:
                     returnline = u""
                 else:
                     if unit.isfuzzy() and not self.includefuzzy or len(unit.target) == 0:
                         value = unit.source
                     else:
-                        value = unit.target
+                        value = self._handle_accesskeys(unit, key)
                     self.inecho = False
                     assert isinstance(value, unicode)
-                    returnline = "%(key)s%(del)s%(value)s%(term)s%(eol)s" % \
-                         {"key": "%s%s%s" % (self.personality.key_wrap_char,
-                                             key,
-                                             self.personality.key_wrap_char),
-                          "del": delimiter,
-                          "value": "%s%s%s" % (self.personality.value_wrap_char,
-                                               self.personality.encode(value),
-                                               self.personality.value_wrap_char),
-                          "term": self.personality.pair_terminator,
-                          "eol": eol,
-                         }
+                    returnline = "%(key)s%(del)s%(value)s%(term)s%(eol)s" % {
+                        "key": "%s%s%s" % (self.personality.key_wrap_char,
+                                           key,
+                                           self.personality.key_wrap_char),
+                        "del": delimiter,
+                        "value": "%s%s%s" % (self.personality.value_wrap_char,
+                                             self.personality.encode(value),
+                                             self.personality.value_wrap_char),
+                        "term": self.personality.pair_terminator,
+                        "eol": eol,
+                    }
             else:
                 self.inecho = True
                 returnline = line + eol
@@ -145,26 +194,33 @@ class reprop:
 
 
 def convertstrings(inputfile, outputfile, templatefile, personality="strings",
-                   includefuzzy=False, encoding=None,
+                   includefuzzy=False, encoding=None, outputthreshold=None,
                    remove_untranslated=False):
     """.strings specific convertor function"""
     return convertprop(inputfile, outputfile, templatefile,
                        personality="strings", includefuzzy=includefuzzy,
-                       encoding=encoding,
+                       encoding=encoding, outputthreshold=outputthreshold,
                        remove_untranslated=remove_untranslated)
 
 
 def convertmozillaprop(inputfile, outputfile, templatefile,
-                       includefuzzy=False, remove_untranslated=False):
+                       includefuzzy=False, remove_untranslated=False,
+                       outputthreshold=None):
     """Mozilla specific convertor function"""
     return convertprop(inputfile, outputfile, templatefile,
                        personality="mozilla", includefuzzy=includefuzzy,
-                       remove_untranslated=remove_untranslated)
+                       remove_untranslated=remove_untranslated,
+                       outputthreshold=outputthreshold)
 
 
 def convertprop(inputfile, outputfile, templatefile, personality="java",
-                includefuzzy=False, encoding=None, remove_untranslated=False):
+                includefuzzy=False, encoding=None, remove_untranslated=False,
+                outputthreshold=None):
     inputstore = po.pofile(inputfile)
+
+    if not convert.should_output_store(inputstore, outputthreshold):
+        return False
+
     if templatefile is None:
         raise ValueError("must have template file for properties files")
         # convertor = po2prop()
@@ -184,7 +240,6 @@ formats = {
 
 def main(argv=None):
     # handle command line options
-    from translate.convert import convert
     parser = convert.ConvertOptionParser(formats, usetemplates=True,
                                          description=__doc__)
     parser.add_option("", "--personality", dest="personality",
@@ -200,6 +255,7 @@ def main(argv=None):
     parser.add_option("", "--removeuntranslated", dest="remove_untranslated",
             default=False, action="store_true",
             help="remove key value from output if it is untranslated")
+    parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.passthrough.append("personality")
     parser.passthrough.append("encoding")
