@@ -24,11 +24,9 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
-try:
-    import textwrap
-except ImportError:
-    textwrap = None
+import textwrap
 
+from translate.convert import convert
 from translate.storage import factory
 
 
@@ -72,9 +70,14 @@ class po2txt:
         return txtresult
 
 
-def converttxt(inputfile, outputfile, templatefile, wrap=None, includefuzzy=False, encoding='utf-8'):
+def converttxt(inputfile, outputfile, templatefile, wrap=None, includefuzzy=False, encoding='utf-8',
+               outputthreshold=None):
     """reads in stdin using fromfileclass, converts using convertorclass, writes to stdout"""
     inputstore = factory.getobject(inputfile)
+
+    if not convert.should_output_store(inputstore, outputthreshold):
+        return False
+
     convertor = po2txt(wrap=wrap)
     if templatefile is None:
         outputstring = convertor.convertstore(inputstore, includefuzzy)
@@ -86,7 +89,6 @@ def converttxt(inputfile, outputfile, templatefile, wrap=None, includefuzzy=Fals
 
 
 def main(argv=None):
-    from translate.convert import convert
     from translate.misc import stdiotell
     import sys
     sys.stdout = stdiotell.StdIOWrapper(sys.stdout)
@@ -95,10 +97,10 @@ def main(argv=None):
     parser.add_option("", "--encoding", dest="encoding", default='utf-8', type="string",
             help="The encoding of the template file (default: UTF-8)")
     parser.passthrough.append("encoding")
-    if textwrap is not None:
-        parser.add_option("-w", "--wrap", dest="wrap", default=None, type="int",
-                help="set number of columns to wrap text at", metavar="WRAP")
-        parser.passthrough.append("wrap")
+    parser.add_option("-w", "--wrap", dest="wrap", default=None, type="int",
+            help="set number of columns to wrap text at", metavar="WRAP")
+    parser.passthrough.append("wrap")
+    parser.add_threshold_option()
     parser.add_fuzzy_option()
     parser.run(argv)
 
