@@ -25,12 +25,10 @@ See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/command
 for examples and usage instructions.
 """
 
-from translate.storage import factory
-from translate.search import match
 from translate.misc.multistring import multistring
+from translate.search import match
+from translate.storage import catkeys, factory, poheader
 from translate.tools import pretranslate
-from translate.storage import poheader, po
-from translate.storage import catkeys
 
 
 def convertpot(input_file, output_file, template_file, tm=None,
@@ -226,8 +224,8 @@ def _do_poheaders(input_store, output_store, template_store):
 
     inputheadervalues = input_store.parseheader()
     for key, value in inputheadervalues.iteritems():
-        if key in ("Project-Id-Version", "Last-Translator", "Language-Team", \
-                   "PO-Revision-Date", "Content-Type", \
+        if key in ("Project-Id-Version", "Last-Translator", "Language-Team",
+                   "PO-Revision-Date", "Content-Type",
                    "Content-Transfer-Encoding", "Plural-Forms"):
             # want to carry these from the template so we ignore them
             pass
