@@ -1,12 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from py.test import mark
-
-from translate.convert import mozlang2po
-from translate.convert import test_convert
+from translate.convert import mozlang2po, test_convert
 from translate.misc import wStringIO
-from translate.storage import po
 from translate.storage import mozilla_lang as lang
 
 
@@ -32,13 +28,13 @@ class TestLang2PO:
         """checks that the pofile contains a single non-header element, and returns it"""
         assert len(pofile.units) == 2
         assert pofile.units[0].isheader()
-        print pofile
+        print(pofile)
         return pofile.units[1]
 
     def countelements(self, pofile):
         """counts the number of non-header entries"""
         assert pofile.units[0].isheader()
-        print pofile
+        print(pofile)
         return len(pofile.units) - 1
 
     def test_simpleentry(self):
