@@ -3,15 +3,11 @@
 
 import warnings
 
-from py import test
-from py.test import mark
+import pytest
 
-from translate.convert import po2dtd
-from translate.convert import dtd2po
-from translate.convert import test_convert
+from translate.convert import dtd2po, po2dtd, test_convert
 from translate.misc import wStringIO
-from translate.storage import po
-from translate.storage import dtd
+from translate.storage import dtd, po
 
 
 class TestPO2DTD:
@@ -22,11 +18,11 @@ class TestPO2DTD:
     def teardown_method(self, method):
         warnings.resetwarnings()
 
-    def po2dtd(self, posource):
+    def po2dtd(self, posource, remove_untranslated=False):
         """helper that converts po source to dtd source without requiring files"""
         inputfile = wStringIO.StringIO(posource)
         inputpo = po.pofile(inputfile)
-        convertor = po2dtd.po2dtd()
+        convertor = po2dtd.po2dtd(remove_untranslated=remove_untranslated)
         outputdtd = convertor.convertstore(inputpo)
         return outputdtd
 
@@ -40,12 +36,13 @@ class TestPO2DTD:
         outputdtd = convertor.convertstore(inputpo)
         return outputdtd
 
-    def convertdtd(self, posource, dtdtemplate):
+    def convertdtd(self, posource, dtdtemplate, remove_untranslated=False):
         """helper to exercise the command line function"""
         inputfile = wStringIO.StringIO(posource)
         outputfile = wStringIO.StringIO()
         templatefile = wStringIO.StringIO(dtdtemplate)
-        assert po2dtd.convertdtd(inputfile, outputfile, templatefile)
+        assert po2dtd.convertdtd(inputfile, outputfile, templatefile,
+                                 remove_untranslated=remove_untranslated)
         return outputfile.getvalue()
 
     def roundtripsource(self, dtdsource):
@@ -62,7 +59,7 @@ class TestPO2DTD:
         dtdresult = dtdoutputfile.getvalue()
         print_string = "Original DTD:\n%s\n\nPO version:\n%s\n\n"
         print_string = print_string + "Output DTD:\n%s\n################"
-        print print_string % (dtdsource, posource, dtdresult)
+        print(print_string % (dtdsource, posource, dtdresult))
         return dtdresult
 
     def roundtripstring(self, entitystring):
@@ -106,10 +103,15 @@ class TestPO2DTD:
 
     def test_missingaccesskey(self):
         """tests that proper warnings are given if access key is missing"""
-        simplepo = '''#: simple.label\n#: simple.accesskey\nmsgid "Simple &String"\nmsgstr "Dimpled Ring"\n'''
-        simpledtd = '''<!ENTITY simple.label "Simple String">\n<!ENTITY simple.accesskey "S">'''
+        simplepo = '''#: simple.label
+#: simple.accesskey
+msgid "Simple &String"
+msgstr "Dimpled Ring"
+'''
+        simpledtd = '''<!ENTITY simple.label "Simple String">
+<!ENTITY simple.accesskey "S">'''
         warnings.simplefilter("error")
-        assert test.raises(Warning, self.merge2dtd, simpledtd, simplepo)
+        assert pytest.raises(Warning, self.merge2dtd, simpledtd, simplepo)
 
     def test_accesskeycase(self):
         """tests that access keys come out with the same case as the original, regardless"""
@@ -132,7 +134,7 @@ class TestPO2DTD:
             simpledtd = simpledtd_template % (en_label, en_akey)
             dtdfile = self.merge2dtd(simpledtd, simplepo)
             dtdfile.makeindex()
-            accel = dtd.unquotefromdtd(dtdfile.index["simple.accesskey"].definition)
+            accel = dtd.unquotefromdtd(dtdfile.id_index["simple.accesskey"].definition)
             assert accel == target_akey
 
     def test_accesskey_types(self):
@@ -145,7 +147,7 @@ class TestPO2DTD:
                 simpledtd = simpledtd_template % (label, accesskey)
                 dtdfile = self.merge2dtd(simpledtd, simplepo)
                 dtdfile.makeindex()
-                assert dtd.unquotefromdtd(dtdfile.index["simple.%s" % accesskey].definition) == "a"
+                assert dtd.unquotefromdtd(dtdfile.id_index["simple.%s" % accesskey].definition) == "a"
 
     def test_ampersandfix(self):
         """tests that invalid ampersands are fixed in the dtd"""
@@ -163,9 +165,77 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
 <!ENTITY searchIntegration.label       "Allow &searchIntegration.engineName; to search messages">'''
         dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
         dtdsource = str(dtdfile)
-        print dtdsource
+        print(dtdsource)
         assert '"&searchIntegration.engineName; ileti aramasına izin ver"' in dtdsource
 
+    def test_accesskey_missing(self):
+        """tests that missing ampersands use the source accesskey"""
+        po_snippet = r'''#: key.label
+#: key.accesskey
+msgid "&Search"
+msgstr "Ileti"
+'''
+        dtd_snippet = r'''<!ENTITY key.accesskey      "S">
+<!ENTITY key.label       "Ileti">'''
+        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
+        dtdsource = str(dtdfile)
+        print(dtdsource)
+        assert '"Ileti"' in dtdsource
+        assert '""' not in dtdsource
+        assert '"S"' in dtdsource
+
+    def test_accesskey_and_amp_case_no_accesskey(self):
+        """tests that accesskey and &amp; can work together
+
+        If missing we use the source accesskey"""
+        po_snippet = r'''#: key.label
+#: key.accesskey
+msgid "Colour & &Light"
+msgstr "Lig en Kleur"
+'''
+        dtd_snippet = r'''<!ENTITY key.accesskey      "L">
+<!ENTITY key.label       "Colour &amp; Light">'''
+        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
+        dtdsource = str(dtdfile)
+        print(dtdsource)
+        assert '"Lig en Kleur"' in dtdsource
+        assert '"L"' in dtdsource
+
+    def test_accesskey_and_amp_case_no_amp(self):
+        """tests that accesskey and &amp; can work together
+
+        If present we use the target accesskey"""
+        po_snippet = r'''#: key.label
+#: key.accesskey
+msgid "Colour & &Light"
+msgstr "Lig en &Kleur"
+'''
+        dtd_snippet = r'''<!ENTITY key.accesskey      "L">
+<!ENTITY key.label       "Colour &amp; Light">'''
+        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
+        dtdsource = str(dtdfile)
+        print(dtdsource)
+        assert '"Lig en Kleur"' in dtdsource
+        assert '"K"' in dtdsource
+
+    def test_accesskey_and_amp_case_both_amp_and_accesskey(self):
+        """tests that accesskey and &amp; can work together
+
+        If present both & (and) and a marker then we use the correct source
+        accesskey"""
+        po_snippet = r'''#: key.label
+#: key.accesskey
+msgid "Colour & &Light"
+msgstr "Lig & &Kleur"
+'''
+        dtd_snippet = r'''<!ENTITY key.accesskey      "L">
+<!ENTITY key.label       "Colour &amp; Light">'''
+        dtdfile = self.merge2dtd(dtd_snippet, po_snippet)
+        dtdsource = str(dtdfile)
+        print(dtdsource)
+        assert '"Lig &amp; Kleur"' in dtdsource
+        assert '"K"' in dtdsource
+
     def test_entities_two(self):
         """test the error ouput when we find two entities"""
         simplestring = '''#: simple.string second.string\nmsgid "Simple String"\nmsgstr "Dimpled Ring"\n'''
@@ -201,16 +271,108 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
         dtdtemplate = '''<!ENTITY simple.label "Simple String">\n<!ENTITY simple.accesskey "S">\n'''
         dtdexpected = '''<!ENTITY simple.label "Dimpled Ring">\n<!ENTITY simple.accesskey "R">\n'''
         newdtd = self.convertdtd(posource, dtdtemplate)
-        print newdtd
+        print(newdtd)
         assert newdtd == dtdexpected
 
+    def test_untranslated_with_template(self):
+        """test removing of untranslated entries in redtd"""
+        posource = '''#: simple.label
+msgid "Simple string"
+msgstr "Dimpled ring"
+
+#: simple.label2
+msgid "Simple string 2"
+msgstr ""
+
+#: simple.label3
+msgid "Simple string 3"
+msgstr "Simple string 3"
+
+#: simple.label4
+#, fuzzy
+msgid "Simple string 4"
+msgstr "simple string four"
+'''
+        dtdtemplate = '''<!ENTITY simple.label "Simple string">
+<!ENTITY simple.label2 "Simple string 2">
+<!ENTITY simple.label3 "Simple string 3">
+<!ENTITY simple.label4 "Simple string 4">
+'''
+        dtdexpected = '''<!ENTITY simple.label "Dimpled ring">
+
+<!ENTITY simple.label3 "Simple string 3">
+
+'''
+        newdtd = self.convertdtd(posource, dtdtemplate, remove_untranslated=True)
+        print(newdtd)
+        assert newdtd == dtdexpected
+
+    def test_untranslated_without_template(self):
+        """test removing of untranslated entries in po2dtd"""
+        posource = '''#: simple.label
+msgid "Simple string"
+msgstr "Dimpled ring"
+
+#: simple.label2
+msgid "Simple string 2"
+msgstr ""
+
+#: simple.label3
+msgid "Simple string 3"
+msgstr "Simple string 3"
+
+#: simple.label4
+#, fuzzy
+msgid "Simple string 4"
+msgstr "simple string four"
+'''
+        dtdexpected = '''<!ENTITY simple.label "Dimpled ring">
+<!ENTITY simple.label3 "Simple string 3">
+'''
+        newdtd = self.po2dtd(posource, remove_untranslated=True)
+        print(newdtd)
+        assert str(newdtd) == dtdexpected
+
+    def test_blank_source(self):
+        """test removing of untranslated entries where source is blank"""
+        posource = '''#: simple.label
+msgid "Simple string"
+msgstr "Dimpled ring"
+
+#: simple.label2
+msgid ""
+msgstr ""
+
+#: simple.label3
+msgid "Simple string 3"
+msgstr "Simple string 3"
+'''
+        dtdtemplate = '''<!ENTITY simple.label "Simple string">
+<!ENTITY simple.label2 "">
+<!ENTITY simple.label3 "Simple string 3">
+'''
+        dtdexpected_with_template = '''<!ENTITY simple.label "Dimpled ring">
+<!ENTITY simple.label2 "">
+<!ENTITY simple.label3 "Simple string 3">
+'''
+
+        dtdexpected_no_template = '''<!ENTITY simple.label "Dimpled ring">
+<!ENTITY simple.label3 "Simple string 3">
+'''
+        newdtd_with_template = self.convertdtd(posource, dtdtemplate, remove_untranslated=True)
+        print(newdtd_with_template)
+        assert newdtd_with_template == dtdexpected_with_template
+        newdtd_no_template = self.po2dtd(posource, remove_untranslated=True)
+        print(newdtd_no_template)
+        assert str(newdtd_no_template) == dtdexpected_no_template
+
     def test_newlines_escapes(self):
         """check that we can handle a \n in the PO file"""
         posource = '''#: simple.label\n#: simple.accesskey\nmsgid "A hard coded newline.\\n"\nmsgstr "Hart gekoeerde nuwe lyne\\n"\n'''
         dtdtemplate = '<!ENTITY  simple.label "A hard coded newline.\n">\n'
         dtdexpected = '''<!ENTITY  simple.label "Hart gekoeerde nuwe lyne\n">\n'''
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
 
     def test_roundtrip_simple(self):
@@ -264,6 +426,13 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
         self.check_roundtrip(r'''"Both Quotes &quot;&quot; '' "''',
                              r'''"Both Quotes &quot;&quot; &apos;&apos; "''')
 
+    def test_roundtrip_amp(self):
+        """Checks that quotes make it through a DTD->PO->DTD roundtrip.
+
+        Quotes may be escaped or not.
+        """
+        self.check_roundtrip('"Colour &amp; Light"')
+
     def test_merging_entries_with_spaces_removed(self):
         """dtd2po removes pretty printed spaces, this tests that we can merge this back into the pretty printed dtd"""
         posource = '''#: simple.label\nmsgid "First line then "\n"next lines."\nmsgstr "Eerste lyne en dan volgende lyne."\n'''
@@ -271,7 +440,7 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
           '                                          next lines.">\n'
         dtdexpected = '<!ENTITY simple.label "Eerste lyne en dan volgende lyne.">\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
 
     def test_preserving_spaces(self):
@@ -280,7 +449,7 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
         dtdtemplate = '<!ENTITY     simple.label         "One">\n'
         dtdexpected = '<!ENTITY     simple.label         "Een">\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
 
     def test_preserving_spaces(self):
@@ -290,13 +459,13 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
         dtdtemplate = '<!ENTITY simple.label "One" >\n'
         dtdexpected = '<!ENTITY simple.label "Een" >\n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
         # Space after >
         dtdtemplate = '<!ENTITY simple.label "One"> \n'
         dtdexpected = '<!ENTITY simple.label "Een"> \n'
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
 
     def test_comments(self):
@@ -304,7 +473,7 @@ msgstr "&searchIntegration.engineName; &ileti aramasına izin ver"
         posource = '''#: name\nmsgid "Text"\nmsgstr "Teks"'''
         dtdtemplate = '''<!ENTITY name "%s">\n<!-- \n\nexample -->\n'''
         dtdfile = self.merge2dtd(dtdtemplate % "Text", posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdtemplate % "Teks"
 
     def test_duplicates(self):
@@ -335,7 +504,7 @@ msgstr "Dipukutshwayo3"
 <!ENTITY bookmarksButton.label "Dipukutshwayo3">
 '''
         dtdfile = self.merge2dtd(dtdtemplate, posource)
-        print dtdfile
+        print(dtdfile)
         assert str(dtdfile) == dtdexpected
 
 
@@ -361,4 +530,6 @@ class TestPO2DTDCommand(test_convert.TestConvertCommand, TestPO2DTD):
         options = test_convert.TestConvertCommand.test_help(self)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--fuzzy")
+        options = self.help_check(options, "--threshold=PERCENT")
+        options = self.help_check(options, "--removeuntranslated")
         options = self.help_check(options, "--nofuzzy", last=True)
