@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2011 Zuza Software Foundation
+# 2013 F Wolff
 #
 # This file is part of translate.
 #
@@ -25,20 +26,21 @@ Derivatives of UnitChecker (like StandardUnitChecker) check translation units,
 and derivatives of TranslationChecker (like StandardChecker) check
 (source, target) translation pairs.
 
-When adding a new test here, please document and explain the behaviour on the
-`wiki <http://translate.sourceforge.net/wiki/toolkit/pofilter_tests>`_.
+When adding a new test here, please document and explain their behaviour on the
+:doc:`pofilter tests </commands/pofilter_tests>` page.
 """
 
+import logging
 import re
 
-from translate.filters import decoration
-from translate.filters import helpers
-from translate.filters import prefilters
-from translate.filters import spelling
-from translate.filters.decorators import (critical, functional, cosmetic,
-                                          extraction)
-from translate.lang import factory
-from translate.lang import data
+from translate.filters import decoration, helpers, prefilters, spelling
+from translate.filters.decorators import (cosmetic, critical, extraction,
+                                          functional)
+from translate.lang import data, factory
+from translate.misc import lru
+
+
+logger = logging.getLogger(__name__)
 
 # These are some regular expressions that are compiled for use in some tests
 
@@ -72,6 +74,8 @@ tag_re = re.compile("<[^>]+>")
 
 gconf_attribute_re = re.compile('"[a-z_]+?"')
 
+# XML/HTML tags in LibreOffice help and readme, exclude short tags
+lo_tag_re = re.compile('''<[/]??[a-z][a-z_\-]+?(?:| +[a-z]+?=".*?") *>''')
 
 def tagname(string):
     """Returns the name of the XML/HTML tag in string"""
@@ -161,11 +165,12 @@ class SeriousFilterFailure(FilterFailure):
 #the property/tag that is specified as None. A non-None value of "value"
 #indicates that the value of the attribute must be taken into account.
 common_ignoretags = [(None, "xml-lang", None)]
-common_canchangetags = [("img", "alt", None),
-                        (None, "title", None),
-                        (None, "dir", None),
-                        (None, "lang", None),
-                       ]
+common_canchangetags = [
+    ("img", "alt", None),
+    (None, "title", None),
+    (None, "dir", None),
+    (None, "lang", None),
+]
 # Actually the title tag is allowed on many tags in HTML (but probably not all)
 
 
@@ -289,7 +294,7 @@ class UnitChecker(object):
 
     #: Categories where each checking function falls into
     #: Function names are used as keys, categories are the values
-    categories =  {}
+    categories = {}
 
 
     def __init__(self, checkerconfig=None, excludefilters=None,
@@ -440,13 +445,13 @@ class UnitChecker(object):
 
             try:
                 filterresult = self.run_test(filterfunction, unit)
-            except FilterFailure, e:
+            except FilterFailure as e:
                 filterresult = False
                 filtermessage = unicode(e)
-            except Exception, e:
+            except Exception as e:
                 if self.errorhandler is None:
-                    raise ValueError("error in filter %s: %r, %r, %s" % \
-                            (functionname, unit.source, unit.target, e))
+                    raise ValueError("error in filter %s: %r, %r, %s" %
+                                     (functionname, unit.source, unit.target, e))
                 else:
                     filterresult = self.errorhandler(functionname, unit.source,
                                                      unit.target, e)
@@ -484,6 +489,9 @@ class TranslationChecker(UnitChecker):
         super(TranslationChecker, self).__init__(checkerconfig, excludefilters,
                                                  limitfilters, errorhandler)
 
+        # caches for spell checking results across units/runs
+        self.source_spell_cache = lru.LRUCachingDict(256, cullsize=5, aggressive_gc=False)
+        self.target_spell_cache = lru.LRUCachingDict(512, cullsize=5, aggressive_gc=False)
 
     def run_test(self, test, unit):
         """Runs the given test on the given unit.
@@ -499,7 +507,7 @@ class TranslationChecker(UnitChecker):
                 try:
                     if not test(self.str1, unicode(pluralform)):
                         filterresult = False
-                except FilterFailure, e:
+                except FilterFailure as e:
                     filterresult = False
                     filtermessages.extend(e.messages)
 
@@ -528,7 +536,7 @@ class TeeChecker:
 
     #: Categories where each checking function falls into
     #: Function names are used as keys, categories are the values
-    categories =  {}
+    categories = {}
 
 
     def __init__(self, checkerconfig=None, excludefilters=None,
@@ -578,8 +586,7 @@ class TeeChecker:
             for filtername in limitfilters:
 
                 if not filtername in self.combinedfilters:
-                    import sys
-                    print >> sys.stderr, "warning: could not find filter %s" % filtername
+                    logger.warning("could not find filter %s", filtername)
 
         return self.combinedfilters
 
@@ -634,9 +641,9 @@ class StandardChecker(TranslationChecker):
         if self.config.notranslatewords:
             words1 = str1.split()
             if len(words1) == 1 and [word for word in words1 if word in self.config.notranslatewords]:
-            #currently equivalent to:
-            #   if len(words1) == 1 and words1[0] in self.config.notranslatewords:
-            #why do we only test for one notranslate word?
+                #currently equivalent to:
+                #   if len(words1) == 1 and words1[0] in self.config.notranslatewords:
+                #why do we only test for one notranslate word?
                 return True
 
         # we could also check for things like str1.isnumeric(), but the test
@@ -842,7 +849,7 @@ class StandardChecker(TranslationChecker):
                         if match2.group('fullvar') != match1.group('fullvar'):
                             raise FilterFailure(u"Different printf variable: %s" % match2.group())
 
-                if str1ord == None:
+                if str1ord is None:
                     raise FilterFailure(u"Added printf variable: %s" % match2.group())
             elif str2key:
                 str1key = None
@@ -860,7 +867,7 @@ class StandardChecker(TranslationChecker):
                         if match1.group('fullvar') != match2.group('fullvar'):
                             raise FilterFailure(u"Different printf variable: %s" % match2.group())
 
-                if str1key == None:
+                if str1key is None:
                     raise FilterFailure(u"Added printf variable: %s" % match2.group())
             else:
                 for var_num1, match1 in enumerate(printf_pat.finditer(str1)):
@@ -885,7 +892,7 @@ class StandardChecker(TranslationChecker):
         return 1
 
 
-    @critical
+    @functional
     def accelerators(self, str1, str2):
         """Checks whether accelerators are consistent between the
         two strings.
@@ -1353,7 +1360,7 @@ class StandardChecker(TranslationChecker):
     @functional
     def filepaths(self, str1, str2):
         """Checks that file paths have not been translated."""
-        for word1 in self.filteraccelerators(str1).split():
+        for word1 in self.filteraccelerators(self.filterxml(str1)).split():
             if word1.startswith(u"/"):
                 if not helpers.countsmatch(str1, str2, (word1,)):
                     raise FilterFailure(u"Different file paths")
@@ -1451,31 +1458,33 @@ class StandardChecker(TranslationChecker):
             return True
 
         # TODO: filterxml?
-        str1 = self.filteraccelerators_by_list(self.filtervariables(str1),
+        str1 = self.filteraccelerators_by_list(self.removevariables(str1),
                                                self.config.sourcelang.validaccel)
-        str2 = self.filteraccelerators_by_list(self.filtervariables(str2),
+        str2 = self.filteraccelerators_by_list(self.removevariables(str2),
                                                self.config.lang.validaccel)
-        ignore1 = []
-        messages = []
+        errors = set()
 
-        for word, index, suggestions in spelling.check(str1, lang="en"):
-            ignore1.append(word)
+        # We cache spelling results of source texts:
+        ignore1 = self.source_spell_cache.get(str1, None)
+        if ignore1 is None:
+            ignore1 = set(spelling.simple_check(str1, lang=self.config.sourcelang.code))
+            self.source_spell_cache[str1] = ignore1
 
-        for word, index, suggestions in spelling.check(str2, lang=self.config.targetlanguage):
-            if word in self.config.notranslatewords:
-                continue
+        # We cache spelling results of target texts sentence-by-sentence. This
+        # way we can reuse most of the results while someone is typing a long
+        # segment in Virtaal.
+        sentences2 = self.config.lang.sentences(str2)
+        for sentence in sentences2:
+            sentence_errors = self.target_spell_cache.get(sentence, None)
+            if sentence_errors is None:
+                sentence_errors = spelling.simple_check(sentence, lang=self.config.targetlanguage)
+                self.target_spell_cache[sentence] = sentence_errors
+            errors.update(sentence_errors)
 
-            if word in ignore1:
-                continue
+        errors.difference_update(ignore1, self.config.notranslatewords)
 
-            # hack to ignore hyphenisation rules
-            if word in suggestions:
-                continue
-
-            messages.append(u"Check the spelling of %s (could be %s)" %
-                            (word, u" / ".join(suggestions[:5])))
-
-        if messages:
+        if errors:
+            messages = [u"Check the spelling of: %s" % u", ".join(errors)]
             raise FilterFailure(messages)
 
         return True
@@ -1504,7 +1513,8 @@ class StandardChecker(TranslationChecker):
                          "isreview", "notranslatewords", "musttranslatewords",
                          "emails", "simpleplurals", "urls", "printf",
                          "tabs", "newlines", "functions", "options",
-                         "blank", "nplurals", "gconf", "dialogsizes"),
+                         "blank", "nplurals", "gconf", "dialogsizes",
+                         "validxml"),
           "blank": ("simplecaps", "variables", "startcaps",
                     "accelerators", "brackets", "endpunc",
                     "acronyms", "xmltags", "startpunc",
@@ -1515,7 +1525,7 @@ class StandardChecker(TranslationChecker):
                     "isreview", "notranslatewords", "musttranslatewords",
                     "emails", "simpleplurals", "urls", "printf",
                     "tabs", "newlines", "functions", "options",
-                    "gconf", "dialogsizes"),
+                    "gconf", "dialogsizes", "validxml"),
           "credits": ("simplecaps", "variables", "startcaps",
                       "accelerators", "brackets", "endpunc",
                       "acronyms", "xmltags", "startpunc",
@@ -1523,7 +1533,8 @@ class StandardChecker(TranslationChecker):
                       "filepaths", "doublespacing",
                       "sentencecount", "numbers",
                       "emails", "simpleplurals", "urls", "printf",
-                      "tabs", "newlines", "functions", "options"),
+                      "tabs", "newlines", "functions", "options",
+                      "validxml"),
          "purepunc": ("startcaps", "options"),
          # This is causing some problems since Python 2.6, as
          # startcaps is now seen as an important one to always execute
@@ -1543,7 +1554,7 @@ class StandardChecker(TranslationChecker):
                           "startwhitespace", "endwhitespace",
                           "singlequoting", "doublequoting",
                           "filepaths", "purepunc", "doublewords", "printf",
-                          "newlines"),
+                          "newlines", "validxml"),
          }
 
 # code to actually run the tests (use unittest?)
@@ -1557,7 +1568,7 @@ openofficeconfig = CheckerConfig(
     ignoretags=[("alt", "xml-lang", None), ("ahelp", "visibility", "visible"),
                 ("img", "width", None), ("img", "height", None)],
     canchangetags=[("link", "name", None)],
-    )
+)
 
 
 class OpenOfficeChecker(StandardChecker):
@@ -1572,13 +1583,64 @@ class OpenOfficeChecker(StandardChecker):
         checkerconfig.update(openofficeconfig)
         StandardChecker.__init__(self, **kwargs)
 
+libreofficeconfig = CheckerConfig(
+    accelmarkers=["~"],
+    varmatches=[("&", ";"), ("%", "%"), ("%", None), ("%", 0), ("$(", ")"),
+                ("$", "$"), ("${", "}"), ("#", "#"), ("#", 1), ("#", 0),
+                ("($", ")"), ("$[", "]"), ("[", "]"), ("@", "@"),
+                ("$", None)],
+    ignoretags=[("alt", "xml-lang", None), ("ahelp", "visibility", "visible"),
+                ("img", "width", None), ("img", "height", None)],
+    canchangetags=[("link", "name", None)],
+)
+
+
+class LibreOfficeChecker(StandardChecker):
+
+    def __init__(self, **kwargs):
+        checkerconfig = kwargs.get("checkerconfig", None)
+
+        if checkerconfig is None:
+            checkerconfig = CheckerConfig()
+            kwargs["checkerconfig"] = checkerconfig
+
+        checkerconfig.update(libreofficeconfig)
+        checkerconfig.update(openofficeconfig)
+        StandardChecker.__init__(self, **kwargs)
+
+
+    @critical
+    def validxml(self, str1, str2):
+        """Check that all XML/HTML open/close tags has close/open
+        pair in the translation."""
+        for location in self.locations:
+            if location.endswith(".xrm") or location.endswith(".xhp"):
+                opentags = []
+                match = re.search(lo_tag_re, str2)
+                while match:
+                    acttag = match.group(0)
+                    if acttag.startswith("</"):
+                        if len(opentags) == 0:
+                            raise FilterFailure(u"There is no open tag for %s" % (acttag))
+                        opentag = opentags.pop()
+                        if tagname(acttag) != "/" + tagname(opentag):
+                            raise FilterFailure(u"Open tag %s and close tag %s "
+                                                 "don't match" % (opentag, acttag))
+                    else:
+                        opentags.append(acttag)
+                    str2 = str2[match.end(0):]
+                    match = re.search(lo_tag_re, str2)
+                if len(opentags) != 0:
+                    raise FilterFailure(u"There is no close tag for %s" % (opentags.pop()))
+        return True
+
 
 mozillaconfig = CheckerConfig(
     accelmarkers=["&"],
     varmatches=[("&", ";"), ("%", "%"), ("%", 1), ("$", "$"), ("$", None),
                 ("#", 1), ("${", "}"), ("$(^", ")"), ("{{", "}}"), ],
     criticaltests=["accelerators"],
-    )
+)
 
 
 class MozillaChecker(StandardChecker):
@@ -1672,10 +1734,18 @@ class MozillaChecker(StandardChecker):
 
         return super(MozillaChecker, self).unchanged(str1, str2)
 
+    @cosmetic
+    def accelerators(self, str1, str2):
+        """Checks whether accelerators are consistent between the
+        two strings.
+
+        For Mozilla we lower the severity to cosmetic.
+        """
+        return super(MozillaChecker, self).accelerators(str1, str2)
 
 drupalconfig = CheckerConfig(
     varmatches=[("%", None), ("@", None), ("!", None)],
-    )
+)
 
 
 class DrupalChecker(StandardChecker):
@@ -1695,7 +1765,7 @@ gnomeconfig = CheckerConfig(
     accelmarkers=["_"],
     varmatches=[("%", 1), ("$(", ")")],
     credit_sources=[u"translator-credits"],
-    )
+)
 
 
 class GnomeChecker(StandardChecker):
@@ -1733,7 +1803,7 @@ kdeconfig = CheckerConfig(
     accelmarkers=["&"],
     varmatches=[("%", 1)],
     credit_sources=[u"Your names", u"Your emails", u"ROLES_OF_TRANSLATORS"],
-    )
+)
 
 
 class KdeChecker(StandardChecker):
@@ -1785,6 +1855,7 @@ class TermChecker(StandardChecker):
 
 projectcheckers = {
     "openoffice": OpenOfficeChecker,
+    "libreoffice": LibreOfficeChecker,
     "mozilla": MozillaChecker,
     "kde": KdeChecker,
     "wx": KdeChecker,
@@ -1792,7 +1863,7 @@ projectcheckers = {
     "creativecommons": CCLicenseChecker,
     "drupal": DrupalChecker,
     "terminology": TermChecker,
-    }
+}
 
 
 class StandardUnitChecker(UnitChecker):
@@ -1854,8 +1925,8 @@ def runtests(str1, str2, ignorelist=()):
     failures = checker.run_filters(unit)
 
     for test in failures:
-        print "failure: %s: %s\n  %r\n  %r" % \
-              (test, failures[test]['message'], str1, str2)
+        print("failure: %s: %s\n  %r\n  %r" % \
+              (test, failures[test]['message'], str1, str2))
 
     return failures
 
@@ -1868,8 +1939,7 @@ def batchruntests(pairs):
         if runtests(str1, str2):
             passed += 1
 
-    print
-    print "total: %d/%d pairs passed" % (passed, numpairs)
+    print("\ntotal: %d/%d pairs passed" % (passed, numpairs))
 
 
 if __name__ == '__main__':
