@@ -19,21 +19,22 @@
 
 """Perform quality checks on Gettext PO, XLIFF and TMX localization files.
 
-Snippet files whenever a test fails.  These can be examined, corrected and
-merged back into the originals using pomerge.
+Snippet files are created whenever a test fails.  These can be examined,
+corrected and merged back into the originals using pomerge.
 
-See: http://translate.sourceforge.net/wiki/toolkit/pofilter for examples and
-usage instructions and http://translate.sourceforge.net/wiki/toolkit/pofilter_tests
+See:
+http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/pofilter.html
+for examples and usage instructions and
+http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/pofilter_tests.html
 for full descriptions of all tests.
 """
 
 import os
 
+from translate.filters import autocorrect, checks
+from translate.misc import optrecurse
 from translate.storage import factory
 from translate.storage.poheader import poheader
-from translate.filters import checks
-from translate.filters import autocorrect
-from translate.misc import optrecurse
 
 
 def build_checkerconfig(options):
@@ -200,10 +201,8 @@ class FilterOptionParser(optrecurse.RecursiveOptionParser):
         options.inputformats = self.inputformats
         options.outputoptions = self.outputoptions
 
-        self.usepsyco(options)
-
         if options.listfilters:
-            print options.checkfilter.getfilterdocs()
+            print(options.checkfilter.getfilterdocs())
         else:
             self.recursiveprocess(options)
 
@@ -252,6 +251,9 @@ def cmdlineparser():
     parser.add_option("", "--openoffice", dest="filterclass",
         action="store_const", default=None, const=checks.OpenOfficeChecker,
         help="use the standard checks for OpenOffice translations")
+    parser.add_option("", "--libreoffice", dest="filterclass",
+        action="store_const", default=None, const=checks.LibreOfficeChecker,
+        help="use the standard checks for LibreOffice translations")
     parser.add_option("", "--mozilla", dest="filterclass",
         action="store_const", default=None, const=checks.MozillaChecker,
         help="use the standard checks for Mozilla translations")
