@@ -22,9 +22,8 @@
 of delimiters"""
 
 import logging
-import htmlentitydefs
 
-from translate.misc.typecheck import accepts, returns
+from six.moves import html_entities
 
 
 def find_all(searchin, substr):
@@ -190,27 +189,66 @@ def extractwithoutquotes(source, startdelim, enddelim, escape=None,
     return (extracted, instring)
 
 
-@accepts(unicode)
-@returns(unicode)
-def htmlentityencode(source):
-    """encodes source using HTML entities e.g. © -> &copy;"""
-    output = u""
-    for char in source:
-        charnum = ord(char)
-        if charnum in htmlentitydefs.codepoint2name:
-            output += u"&%s;" % htmlentitydefs.codepoint2name[charnum]
-        else:
-            output += str(char)
-    return output
+def _encode_entity_char(char, codepoint2name):
+    charnum = ord(char)
+    if charnum in codepoint2name:
+        return u"&%s;" % codepoint2name[charnum]
+    else:
+        return char
 
+def entityencode(source, codepoint2name):
+    """Encode ``source`` using entities from ``codepoint2name``.
 
-@accepts(unicode)
-@returns(unicode)
-def htmlentitydecode(source):
-    """decodes source using HTML entities e.g. &copy; -> ©"""
+    :param unicode source: Source string to encode
+    :param dict codepoint2name: Dictionary mapping code points to entity names
+           (without the the leading ``&`` or the trailing ``;``)
+    """
     output = u""
     inentity = False
     for char in source:
+        if char == "&":
+            inentity = True
+            possibleentity = ""
+            continue
+        if inentity:
+            if char == ";":
+                output += "&" + possibleentity + ";"
+                inentity = False
+            elif char == " ":
+                output += _encode_entity_char("&", codepoint2name) + \
+                          entityencode(possibleentity + char, codepoint2name)
+                inentity = False
+            else:
+                possibleentity += char
+        else:
+            output += _encode_entity_char(char, codepoint2name)
+    if inentity:
+        # Handle nonentities at end of string.
+        output += _encode_entity_char("&", codepoint2name) + \
+                  entityencode(possibleentity, codepoint2name)
+
+    return output
+
+
+def _has_entity_end(source):
+    for char in source:
+        if char == ";":
+            return True
+        elif char == " ":
+            return False
+    return False
+
+def entitydecode(source, name2codepoint):
+    """Decode ``source`` using entities from ``name2codepoint``.
+
+    :param unicode source: Source string to decode
+    :param dict name2codepoint: Dictionary mapping entity names (without the
+           the leading ``&`` or the trailing ``;``) to code points
+    """
+    output = u""
+    inentity = False
+    for i, char in enumerate(source):
+        char = source[i]
         if char == "&":
             inentity = True
             possibleentity = ""
@@ -218,8 +256,12 @@ def htmlentitydecode(source):
         if inentity:
             if char == ";":
                 if (len(possibleentity) > 0 and
-                    possibleentity in htmlentitydefs.name2codepoint):
-                    output += unichr(htmlentitydefs.name2codepoint[possibleentity])
+                    possibleentity in name2codepoint):
+                    entchar = unichr(name2codepoint[possibleentity])
+                    if entchar == u'&' and _has_entity_end(source[i+1:]):
+                        output += "&" + possibleentity + ";"
+                    else:
+                        output += entchar
                     inentity = False
                 else:
                     output += "&" + possibleentity + ";"
@@ -231,11 +273,28 @@ def htmlentitydecode(source):
                 possibleentity += char
         else:
             output += char
+    if inentity:
+        # Handle nonentities at end of string.
+        output += "&" + possibleentity
     return output
 
 
-@accepts(unicode)
-@returns(unicode)
+def htmlentityencode(source):
+    """Encode ``source`` using HTML entities e.g. © -> ``&copy;``
+
+    :param unicode source: Source string to encode
+    """
+    return entityencode(source, html_entities.codepoint2name)
+
+
+def htmlentitydecode(source):
+    """Decode source using HTML entities e.g. ``&copy;`` -> ©.
+
+    :param unicode source: Source string to decode
+    """
+    return entitydecode(source, html_entities.name2codepoint)
+
+
 def javapropertiesencode(source):
     """Encodes source in the escaped-unicode encoding used by Java
     .properties files
@@ -254,8 +313,6 @@ def javapropertiesencode(source):
     return output
 
 
-@accepts(unicode)
-@returns(unicode)
 def mozillapropertiesencode(source):
     """Encodes source in the escaped-unicode encoding used by Mozilla
     .properties files.
@@ -268,18 +325,40 @@ def mozillapropertiesencode(source):
             output += char
     return output
 
+def escapespace(char):
+    assert(len(char) == 1)
+    if char.isspace():
+        return u"\\u%04X" %(ord(char))
+    return char
+
+def mozillaescapemarginspaces(source):
+    """Escape leading and trailing spaces for Mozilla .properties files."""
+    if not source:
+        return u""
+
+    if len(source) == 1 and source.isspace():
+        # FIXME: This is hack for people using white-space to mark empty
+        # Mozilla strings translated, drop this once we have better way to
+        # handle this in Pootle.
+        return u""
+
+    if len(source) == 1:
+        return escapespace(source)
+    else:
+        return escapespace(source[0]) + source[1:-1] + escapespace(source[-1])
+
 propertyescapes = {
     # escapes that are self-escaping
     "\\": "\\", "'": "'", '"': '"',
     # control characters that we keep
     "f": "\f", "n": "\n", "r": "\r", "t": "\t",
-    }
+}
 
 controlchars = {
     # the reverse of the above...
     "\\": "\\\\",
     "\f": "\\f", "\n": "\\n", "\r": "\\r", "\t": "\\t",
-    }
+}
 
 
 def escapecontrols(source):
@@ -289,8 +368,6 @@ def escapecontrols(source):
     return source
 
 
-@accepts(unicode)
-@returns(unicode)
 def propertiesdecode(source):
     """Decodes source from the escaped-unicode encoding used by .properties
     files.
@@ -314,8 +391,7 @@ def propertiesdecode(source):
             # we just return the character, unescaped
             # if people want to escape them they can use escapecontrols
             return unichr(i)
-        else:
-            return "\\u%04x" % i
+        return "\\u%04x" % i
 
     while s < len(source):
         c = source[s]
@@ -342,16 +418,18 @@ def propertiesdecode(source):
             digits = 4
             x = 0
             for digit in range(digits):
-                x <<= 4
                 if s + digit >= len(source):
                     digits = digit
                     break
                 c = source[s + digit].lower()
-                if c.isdigit():
-                    x += ord(c) - ord('0')
-                elif c in "abcdef":
-                    x += ord(c) - ord('a') + 10
+                if c.isdigit() or c in "abcdef":
+                    x <<= 4
+                    if c.isdigit():
+                        x += ord(c) - ord('0')
+                    else:
+                        x += ord(c) - ord('a') + 10
                 else:
+                    digits = digit
                     break
             s += digits
             output += unichr2(x)
