@@ -74,8 +74,18 @@ class TestEncoding:
         assert quote.mozillapropertiesencode(u"abcḓ") == u"abcḓ"
         assert quote.mozillapropertiesencode(u"abc\n") == u"abc\\n"
 
+    def test_escapespace(self):
+        assert quote.escapespace(u" ") == u"\\u0020"
+        assert quote.escapespace(u"\t") == u"\\u0009"
+
+    def test_mozillaescapemarginspaces(self):
+        assert quote.mozillaescapemarginspaces(u" ") == u""
+        assert quote.mozillaescapemarginspaces(u"A") == u"A"
+        assert quote.mozillaescapemarginspaces(u" abc ") == u"\\u0020abc\\u0020"
+        assert quote.mozillaescapemarginspaces(u"  abc ") == u"\\u0020 abc\\u0020"
+
     def test_mozilla_control_escapes(self):
-        """test that we do \uNNNN escapes for certain control characters instead of converting to UTF-8 characters"""
+        r"""test that we do \uNNNN escapes for certain control characters instead of converting to UTF-8 characters"""
         prefix, suffix = "bling", "blang"
         for control in (u"\u0005", u"\u0006", u"\u0007", u"\u0011"):
             string = prefix + control + suffix
@@ -87,6 +97,14 @@ class TestEncoding:
         assert quote.propertiesdecode(u"abc\u1E13") == u"abcḓ"
         assert quote.propertiesdecode(u"abc\N{LEFT CURLY BRACKET}") == u"abc{"
         assert quote.propertiesdecode(u"abc\\") == u"abc\\"
+        assert quote.propertiesdecode(u"abc\\") == u"abc\\"
+
+    def test_properties_decode_slashu(self):
+        assert quote.propertiesdecode(u"abc\u1e13") == u"abcḓ"
+        assert quote.propertiesdecode(u"abc\u0020") == u"abc "
+        # NOTE Java only accepts 4 digit unicode, Mozilla accepts two
+        # unfortunately, but it seems harmless to accept both.
+        assert quote.propertiesdecode("abc\u20") == u"abc "
 
     def _html_encoding_helper(self, pairs):
         for from_, to in pairs:
@@ -98,16 +116,25 @@ class TestEncoding:
         raw_encoded = [(u"€", u"&euro;"), (u"©", u"&copy;"), (u'"', u"&quot;")]
         self._html_encoding_helper(raw_encoded)
 
+    def test_htmlencoding_existing_entities(self):
+        """test that we don't mess existing entities"""
+        assert quote.htmlentityencode(u"&amp;") == u"&amp;"
+
     def test_htmlencoding_passthrough(self):
         """test that we can encode and decode things that look like HTML entities but aren't"""
-        raw_encoded = [(u"copy quot", u"copy quot"),      # Raw text should have nothing done to it.
-                      ]
+        raw_encoded = [(u"copy quot", u"copy quot"),]     # Raw text should have nothing done to it.
         self._html_encoding_helper(raw_encoded)
 
     def test_htmlencoding_nonentities(self):
         """tests to give us full coverage"""
         for encoded, real in [(u"Some &; text", u"Some &; text"),
                               (u"&copy ", u"&copy "),
-                              (u"&rogerrabbit;", u"&rogerrabbit;"),
-                             ]:
+                              (u"&copy", u"&copy"),
+                              (u"&rogerrabbit;", u"&rogerrabbit;"),]:
             assert quote.htmlentitydecode(encoded) == real
+
+        for decoded, real in [(u"Some &; text", u"Some &; text"),
+                              (u"&copy ", u"&amp;copy "),
+                              (u"&copy", u"&amp;copy"),
+                              (u"&rogerrabbit;", u"&rogerrabbit;"),]:
+            assert quote.htmlentityencode(decoded) == real
