@@ -23,8 +23,7 @@
 
 """A class to manage Mozilla .lang files."""
 
-from translate.storage import base
-from translate.storage import txt
+from translate.storage import base, txt
 
 
 class LangUnit(base.TranslationUnit):
@@ -39,7 +38,7 @@ class LangUnit(base.TranslationUnit):
             unchanged = " {ok}"
         else:
             unchanged = ""
-        if self.target == "" or self.target is None:
+        if not self.istranslated():
             target = self.source
         else:
             target = self.target
@@ -59,10 +58,10 @@ class LangStore(txt.TxtFile):
     """We extend TxtFile, since that has a lot of useful stuff for encoding"""
     UnitClass = LangUnit
 
-    Name = _("Mozilla .lang")
+    Name = "Mozilla .lang"
     Extensions = ['lang']
 
-    def __init__(self, inputfile=None, flavour=None, encoding="utf-8", mark_active=True):
+    def __init__(self, inputfile=None, flavour=None, encoding="utf-8", mark_active=False):
         self.is_active = False
         self.mark_active = mark_active
         super(LangStore, self).__init__(inputfile, flavour, encoding)
@@ -81,16 +80,18 @@ class LangStore(txt.TxtFile):
                 self.is_active = True
                 continue
 
-            if len(line) == 0:  # Skip blank lines
+            if len(line) == 0 and not readyTrans:  # Skip blank lines
                 continue
 
             if readyTrans:  # If we are expecting a translation, set the target
                 if line != u.source:
                     u.target = line.replace(" {ok}", "")
+                else:
+                    u.target = ""
                 readyTrans = False  # We already have our translation
                 continue
 
-            if line.startswith('#'): # A comment
+            if line.startswith('#'):  # A comment
                 comment += line[1:].strip() + "\n"
 
             if line.startswith(';'):
