@@ -21,10 +21,9 @@
 import re
 import urllib
 
-from translate.storage import base
-from translate.storage import poheader
+from translate.storage import base, poheader
 from translate.storage.workflow import StateEnum as state
-from translate.misc.typecheck import accepts, returns
+
 
 msgid_comment_re = re.compile("_: (.*?)\n")
 
@@ -45,15 +44,13 @@ def quote_plus(text):
     return urllib.quote_plus(text.encode("utf-8"))
 
 
-@accepts(unicode)
-@returns(unicode)
 def unquote_plus(text):
     """unquote('%7e/abc+def') -> '~/abc def'"""
     try:
         if isinstance(text, unicode):
             text = text.encode('utf-8')
         return urllib.unquote_plus(text).decode('utf-8')
-    except UnicodeEncodeError, e:
+    except UnicodeEncodeError as e:
         # for some reason there is a non-ascii character here. Let's assume it
         # is already unicode (because of originally decoding the file)
         return text
@@ -185,7 +182,7 @@ class pounit(base.TranslationUnit):
 def encodingToUse(encoding):
     """Tests whether the given encoding is known in the python runtime, or returns utf-8.
     This function is used to ensure that a valid encoding is always used."""
-    if encoding == "CHARSET" or encoding == None:
+    if encoding == "CHARSET" or encoding is None:
         return 'utf-8'
     return encoding
 #    if encoding is None: return False
@@ -198,7 +195,7 @@ def encodingToUse(encoding):
 
 
 class pofile(poheader.poheader, base.TranslationStore):
-    Name = _("Gettext PO file")  # pylint: disable=E0602
+    Name = "Gettext PO file"  # pylint: disable=E0602
     Mimetypes = ["text/x-gettext-catalog", "text/x-gettext-translation", "text/x-po", "text/x-pot"]
     Extensions = ["po", "pot"]
     # We don't want windows line endings on Windows:
