@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from translate.storage import test_base
-from translate.storage import catkeys
+from translate.storage import catkeys, test_base
 
 
 class TestCatkeysUnit(test_base.TestTranslationUnit):
@@ -20,8 +19,8 @@ class TestCatkeysUnit(test_base.TestTranslationUnit):
                     '\\\n', '\\\t', '\\\\r', '\\\\"']
         for special in specials:
             unit.source = special
-            print "unit.source:", repr(unit.source) + '|'
-            print "special:", repr(special) + '|'
+            print("unit.source:", repr(unit.source) + '|')
+            print("special:", repr(special) + '|')
             assert unit.source == special
 
     def test_newlines(self):
