@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from translate.storage import test_base
-from translate.storage import wordfast as wf
+from translate.storage import test_base, wordfast as wf
 
 
 class TestWFTime(object):
@@ -10,14 +9,14 @@ class TestWFTime(object):
     def test_timestring(self):
         """Setting and getting times set using a timestring"""
         wftime = wf.WordfastTime()
-        assert wftime.timestring == None
+        assert wftime.timestring is None
         wftime.timestring = "19710820~050000"
         assert wftime.time[:6] == (1971, 8, 20, 5, 0, 0)
 
     def test_time(self):
         """Setting and getting times set using time tuple"""
         wftime = wf.WordfastTime()
-        assert wftime.time == None
+        assert wftime.time is None
         wftime.time = (1999, 3, 27)
         wftime.timestring = "19990327~000000"
 
@@ -37,8 +36,8 @@ class TestWFUnit(test_base.TestTranslationUnit):
                     '\\\n', '\\\t', '\\\\r', '\\\\"']
         for special in specials:
             unit.source = special
-            print "unit.source:", repr(unit.source) + '|'
-            print "special:", repr(special) + '|'
+            print("unit.source:", repr(unit.source) + '|')
+            print("special:", repr(special) + '|')
             assert unit.source == special
 
     def test_wordfast_escaping(self):
@@ -46,7 +45,7 @@ class TestWFUnit(test_base.TestTranslationUnit):
 
         def compare(real, escaped):
             unit = self.UnitClass(real)
-            print real.encode('utf-8'), unit.source.encode('utf-8')
+            print(real.encode('utf-8'), unit.source.encode('utf-8'))
             assert unit.source == real
             assert unit.dict['source'] == escaped
             unit.target = real
