@@ -24,13 +24,13 @@ This will eventually replace the older ts.py which only supports the older
 format. While converters haven't been updated to use this module, we retain
 both.
 
-`TS file format 4.3 <http://doc.trolltech.com/4.3/linguist-ts-file-format.html>`_,
-`4.5 <http://doc.trolltech.com/4.5/linguist-ts-file-format.html>`_,
-`Example <http://svn.ez.no/svn/ezcomponents/trunk/Translation/docs/linguist-format.txt>`_,
-`Plurals forms <http://www.koders.com/cpp/fidE7B7E83C54B9036EB7FA0F27BC56BCCFC4B9DF34.aspx#L200>`_
+`TS file format 4.3 <http://doc.qt.digia.com/4.3/linguist-ts-file-format.html>`_,
+`4.8 <http://qt-project.org/doc/qt-4.8/linguist-ts-file-format.html>`_,
+`5.0 <http://qt-project.org/doc/qt-5.0/qtlinguist/linguist-ts-file-format.html>`_.
+`Example <http://svn.ez.no/svn/ezcomponents/trunk/Translation/docs/linguist-format.txt>`_.
 
-`Specification of the valid variable entries  <http://doc.trolltech.com/4.3/qstring.html#arg>`_,
-`2  <http://doc.trolltech.com/4.3/qstring.html#arg-2>`_
+`Specification of the valid variable entries <http://qt-project.org/doc/qt-5.0/qtcore/qstring.html#arg>`_,
+`2 <http://qt-project.org/doc/qt-5.0/qtcore/qstring.html#arg-2>`_
 """
 
 from lxml import etree
@@ -41,25 +41,26 @@ from translate.storage import base, lisa
 from translate.storage.placeables import general
 from translate.storage.workflow import StateEnum as state
 
+
 # TODO: handle translation types
 
 NPLURALS = {
-'jp': 1,
-'en': 2,
-'fr': 2,
-'lv': 3,
-'ga': 3,
-'cs': 3,
-'sk': 3,
-'mk': 3,
-'lt': 3,
-'ru': 3,
-'pl': 3,
-'ro': 3,
-'sl': 4,
-'mt': 4,
-'cy': 5,
-'ar': 6,
+    'jp': 1,
+    'en': 2,
+    'fr': 2,
+    'lv': 3,
+    'ga': 3,
+    'cs': 3,
+    'sk': 3,
+    'mk': 3,
+    'lt': 3,
+    'ru': 3,
+    'pl': 3,
+    'ro': 3,
+    'sl': 4,
+    'mt': 4,
+    'cy': 5,
+    'ar': 6,
 }
 
 
@@ -101,8 +102,8 @@ class tsunit(lisa.LISAunit):
         if purpose == "target":
             purpose = "translation"
         langset = etree.Element(self.namespaced(purpose))
-        #TODO: check language
-#        lisa.setXMLlang(langset, lang)
+        # TODO: check language
+        #lisa.setXMLlang(langset, lang)
 
         langset.text = text
         return langset
@@ -195,7 +196,7 @@ class tsunit(lisa.LISAunit):
             note.text = text.strip()
 
     def getnotes(self, origin=None):
-        #TODO: consider only responding when origin has certain values
+        # TODO: consider only responding when origin has certain values
         comments = []
         if origin in ["programmer", "developer", "source code", None]:
             notenode = self.xmlelement.find(self.namespaced("extracomment"))
@@ -248,13 +249,17 @@ class tsunit(lisa.LISAunit):
             self._settype(None)
 
     def getid(self):
-        if self.source is None:
-            return None
         context_name = self.getcontext()
-        #XXX: context_name is not supposed to be able to be None (the <name>
+        if self.source is None and context_name is None:
+            return None
+
+        # XXX: context_name is not supposed to be able to be None (the <name>
         # tag is compulsary in the <context> tag)
         if context_name is not None:
-            return context_name + self.source
+            if self.source:
+                return context_name + self.source
+            else:
+                return context_name
         else:
             return self.source
 
@@ -280,6 +285,9 @@ class tsunit(lisa.LISAunit):
         commentnode = self.xmlelement.find(self.namespaced("comment"))
         if commentnode is not None and commentnode.text is not None:
             contexts.append(commentnode.text)
+        message_id = self.xmlelement.get('id')
+        if message_id is not None:
+            contexts.append(message_id)
         contexts = filter(None, contexts)
         return '\n'.join(contexts)
 
@@ -312,7 +320,7 @@ class tsunit(lisa.LISAunit):
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         super(tsunit, self).merge(otherunit, overwrite, comments)
-        #TODO: check if this is necessary:
+        # TODO: check if this is necessary:
         if otherunit.isfuzzy():
             self.markfuzzy()
         else:
@@ -346,7 +354,7 @@ class tsunit(lisa.LISAunit):
 class tsfile(lisa.LISAfile):
     """Class representing a TS file store."""
     UnitClass = tsunit
-    Name = _("Qt Linguist Translation File")
+    Name = "Qt Linguist Translation File"
     Mimetypes = ["application/x-linguist"]
     Extensions = ["ts"]
     rootNode = "TS"
@@ -472,18 +480,6 @@ class tsfile(lisa.LISAfile):
             return 1
 
     def __str__(self):
-        """Converts to a string containing the file's XML.
-
-        We have to override this to ensure mimic the Qt convention:
-            - no XML decleration
-            - plain DOCTYPE that lxml seems to ignore
-        """
-        # A bug in lxml means we have to output the doctype ourselves. For
-        # more information, see:
-        # http://codespeak.net/pipermail/lxml-dev/2008-October/004112.html
-        # The problem was fixed in lxml 2.1.3
-        output = etree.tostring(self.document, pretty_print=True,
-                                xml_declaration=False, encoding='utf-8')
-        if not "<!DOCTYPE TS>" in output[:30]:
-            output = "<!DOCTYPE TS>" + output
-        return output
+        """Converts to a string containing the file's XML."""
+        return etree.tostring(self.document, pretty_print=True,
+                              xml_declaration=True, encoding='utf-8')
