@@ -28,9 +28,10 @@ from lxml import etree
 from translate.misc.multistring import multistring
 from translate.storage import base, lisa
 from translate.storage.lisa import getXMLspace
-from translate.storage.placeables.lisa import xml_to_strelem, strelem_to_xml
+from translate.storage.placeables.lisa import strelem_to_xml, xml_to_strelem
 from translate.storage.workflow import StateEnum as state
 
+
 # TODO: handle translation types
 
 ID_SEPARATOR = u"\04"
@@ -52,7 +53,7 @@ class xliffunit(lisa.LISAunit):
 
     _default_xml_space = "default"
 
-    #TODO: id and all the trans-unit level stuff
+    # TODO: id and all the trans-unit level stuff
 
     S_UNTRANSLATED = state.EMPTY
     S_NEEDS_TRANSLATION = state.NEEDS_WORK
@@ -184,8 +185,8 @@ class xliffunit(lisa.LISAunit):
         :param txt: Alternative translation of the source text.
         """
 
-        #TODO: support adding a source tag ad match quality attribute.  At
-        # the source tag is needed to inject fuzzy matches from a TM.
+        # TODO: support adding a source tag ad match quality attribute.  At the
+        # source tag is needed to inject fuzzy matches from a TM.
         if isinstance(txt, str):
             txt = txt.decode("utf-8")
         alttrans = etree.SubElement(self.xmlelement, self.namespaced("alt-trans"))
@@ -226,8 +227,8 @@ class xliffunit(lisa.LISAunit):
                 targetnode = node.iterdescendants(self.namespaced("target"))
                 newunit.target = lisa.getText(targetnode.next(),
                                               getXMLspace(node, self._default_xml_space))
-                #TODO: support multiple targets better
-                #TODO: support notes in alt-trans
+                # TODO: support multiple targets better
+                # TODO: support notes in alt-trans
                 newunit.xmlelement = node
 
                 translist.append(newunit)
@@ -285,7 +286,7 @@ class xliffunit(lisa.LISAunit):
 
     def adderror(self, errorname, errortext):
         """Adds an error message to this unit."""
-        #TODO: consider factoring out: some duplication between XLIFF and TMX
+        # TODO: consider factoring out: some duplication between XLIFF and TMX
         text = errorname
         if errortext:
             text += ': ' + errortext
@@ -293,7 +294,7 @@ class xliffunit(lisa.LISAunit):
 
     def geterrors(self):
         """Get all error messages."""
-        #TODO: consider factoring out: some duplication between XLIFF and TMX
+        # TODO: consider factoring out: some duplication between XLIFF and TMX
         notelist = self._getnotelist(origin="pofilter")
         errordict = {}
         for note in notelist:
@@ -321,7 +322,7 @@ class xliffunit(lisa.LISAunit):
         if not self.isapproved() and state_n > self.S_UNREVIEWED:
             state_n = self.S_UNREVIEWED
 
-        return  state_n
+        return state_n
 
     def set_state_n(self, value):
         if value not in self.statemap_r:
@@ -329,7 +330,7 @@ class xliffunit(lisa.LISAunit):
 
         targetnode = self.getlanguageNode(lang=None, index=1)
 
-        #FIXME: handle state qualifiers
+        # FIXME: handle state qualifiers
         if value == self.S_UNTRANSLATED:
             if targetnode is not None and "state" in targetnode.attrib:
                 del targetnode.attrib["state"]
@@ -368,10 +369,10 @@ class xliffunit(lisa.LISAunit):
             self.set_state_n(self.S_UNREVIEWED)
 
     def isfuzzy(self):
-#        targetnode = self.getlanguageNode(lang=None, index=1)
-#        return not targetnode is None and \
-#                (targetnode.get("state-qualifier") == "fuzzy-match" or \
-#                targetnode.get("state") == "needs-review-translation")
+        # targetnode = self.getlanguageNode(lang=None, index=1)
+        # return not targetnode is None and \
+        #         (targetnode.get("state-qualifier") == "fuzzy-match" or \
+        #         targetnode.get("state") == "needs-review-translation")
         return not self.isapproved() and bool(self.target)
 
     def markfuzzy(self, value=True):
@@ -464,7 +465,7 @@ class xliffunit(lisa.LISAunit):
         """Returns the contexts in the context groups with the specified name"""
         groups = []
         grouptags = self.xmlelement.iterdescendants(self.namespaced("context-group"))
-        #TODO: conbine name in query
+        # TODO: conbine name in query
         for group in grouptags:
             if group.get("name") == name:
                 contexts = group.iterdescendants(self.namespaced("context"))
@@ -479,7 +480,7 @@ class xliffunit(lisa.LISAunit):
         return self.xmlelement.get("restype")
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
-        #TODO: consider other attributes like "approved"
+        # TODO: consider other attributes like "approved"
         super(xliffunit, self).merge(otherunit, overwrite, comments)
         if self.target:
             self.marktranslated()
@@ -492,7 +493,7 @@ class xliffunit(lisa.LISAunit):
 
     def correctorigin(self, node, origin):
         """Check against node tag's origin (e.g note or alt-trans)"""
-        if origin == None:
+        if origin is None:
             return True
         elif origin in node.get("from", ""):
             return True
@@ -501,6 +502,7 @@ class xliffunit(lisa.LISAunit):
         else:
             return False
 
+    @classmethod
     def multistring_to_rich(cls, mstr):
         """Override :meth:`TranslationUnit.multistring_to_rich` which is used
         by the ``rich_source`` and ``rich_target`` properties."""
@@ -511,19 +513,18 @@ class xliffunit(lisa.LISAunit):
             strings = [mstr]
 
         return [xml_to_strelem(s) for s in strings]
-    multistring_to_rich = classmethod(multistring_to_rich)
 
+    @classmethod
     def rich_to_multistring(cls, elem_list):
         """Override :meth:`TranslationUnit.rich_to_multistring` which is used
         by the ``rich_source`` and ``rich_target`` properties."""
         return multistring([unicode(elem) for elem in elem_list])
-    rich_to_multistring = classmethod(rich_to_multistring)
 
 
 class xlifffile(lisa.LISAfile):
     """Class representing a XLIFF file store."""
     UnitClass = xliffunit
-    Name = _("XLIFF Translation File")
+    Name = "XLIFF Translation File"
     Mimetypes = ["application/x-xliff", "application/x-xliff+xml"]
     Extensions = ["xlf", "xliff", "sdlxliff"]
     rootNode = "xliff"
@@ -536,6 +537,8 @@ class xlifffile(lisa.LISAfile):
 </file>
 </xliff>'''
     namespace = 'urn:oasis:names:tc:xliff:document:1.1'
+    unversioned_namespace = 'urn:oasis:names:tc:xliff:document:'
+
     suggestions_in_format = True
     """xliff units have alttrans tags which can be used to store suggestions"""
 
@@ -545,7 +548,15 @@ class xlifffile(lisa.LISAfile):
         self._messagenum = 0
 
     def initbody(self):
-        self.namespace = self.document.getroot().nsmap.get(None, None)
+        # detect the xliff namespace, handle both 1.1 and 1.2
+        for prefix, ns in self.document.getroot().nsmap.items():
+            if ns and ns.startswith(self.unversioned_namespace):
+                self.namespace = ns
+                break
+        else:
+            # handle crappy xliff docs without proper namespace declaration
+            # by simply using the xmlns default namespace
+            self.namespace = self.document.getroot().nsmap.get(None, None)
 
         if self._filename:
             filenode = self.getfilenode(self._filename, createifmissing=True)
@@ -743,11 +754,11 @@ class xlifffile(lisa.LISAfile):
         if self.body is None:
             return False
         self._messagenum = len(list(self.body.iterdescendants(self.namespaced("trans-unit"))))
-        #TODO: was 0 based before - consider
+        # TODO: was 0 based before - consider
     #    messagenum = len(self.units)
-        #TODO: we want to number them consecutively inside a body/file tag
-        #instead of globally in the whole XLIFF file, but using len(self.units)
-        #will be much faster
+        # TODO: we want to number them consecutively inside a body/file tag
+        # instead of globally in the whole XLIFF file, but using
+        # len(self.units) will be much faster
         return True
 
     def creategroup(self, filename="NoName", createifmissing=False, restype=None):
@@ -764,15 +775,15 @@ class xlifffile(lisa.LISAfile):
         self.removedefaultfile()
         return super(xlifffile, self).__str__()
 
+    @classmethod
     def parsestring(cls, storestring):
         """Parses the string to return the correct file object"""
         xliff = super(xlifffile, cls).parsestring(storestring)
         if xliff.units:
             header = xliff.units[0]
-            if ("gettext-domain-header" in (header.getrestype() or "") \
-                    or xliff.getdatatype() == "po") \
-                    and cls.__name__.lower() != "poxlifffile":
+            if (("gettext-domain-header" in (header.getrestype() or "") or
+                 xliff.getdatatype() == "po") and
+                 cls.__name__.lower() != "poxlifffile"):
                 from translate.storage import poxliff
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
         return xliff
-    parsestring = classmethod(parsestring)
