@@ -29,8 +29,8 @@ for examples and usage instructions.
 import os
 import sys
 
-from translate.storage import po
 from translate.misc import optrecurse
+from translate.storage import po
 
 
 class SplitOptionParser(optrecurse.RecursiveOptionParser):
@@ -47,7 +47,8 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
         """sets the usage string - if usage not given, uses getusagestring for each option"""
         if usage is None:
             self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
-            "\n  input directory is searched for PO files with (poconflicts) comments, all entries are written to files in a directory structure for pomerge"
+                         "\n  " + \
+                         "input directory is searched for PO files with (poconflicts) comments, all entries are written to files in a directory structure for pomerge"
         else:
             super(SplitOptionParser, self).set_usage(usage)
 
@@ -56,7 +57,8 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
         if not self.isrecursive(options.output, 'output'):
             try:
                 self.warning("Output directory does not exist. Attempting to create")
-                #TODO: maybe we should only allow it to be created, otherwise we mess up an existing tree...
+                # TODO: maybe we should only allow it to be created, otherwise
+                # we mess up an existing tree.
                 os.mkdir(options.output)
             except:
                 self.error(optrecurse.optparse.OptionValueError("Output directory does not exist, attempt to create failed"))
@@ -77,7 +79,7 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
             fullinputpath = self.getfullinputpath(options, inputpath)
             try:
                 success = self.processfile(options, fullinputpath)
-            except Exception, error:
+            except Exception as error:
                 if isinstance(error, KeyboardInterrupt):
                     raise self.warning("Error processing: input %s" % (fullinputpath), options, sys.exc_info())
                 success = False
@@ -95,7 +97,7 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
                         if comment.find("# (poconflicts)") == 0:
                             pounit.othercomments.remove(comment)
                             break
-                    #TODO: refactor writing out
+                    # TODO: refactor writing out
                     outputpath = comment[comment.find(")") + 2:].strip()
                     self.checkoutputsubdir(options, os.path.dirname(outputpath))
                     fulloutputpath = os.path.join(options.output, outputpath)
@@ -110,7 +112,8 @@ class SplitOptionParser(optrecurse.RecursiveOptionParser):
 
 
 def main():
-    #outputfile extentions will actually be determined by the comments in the po files
+    # outputfile extentions will actually be determined by the comments in the
+    # po files
     pooutput = ("po", None)
     formats = {(None, None): pooutput, ("po", "po"): pooutput, "po": pooutput}
     parser = SplitOptionParser(formats, description=__doc__)
